[![PyPI Version](https://img.shields.io/pypi/v/gv100ad-py.svg)](https://pypi.python.org/pypi/gv100ad-py)
![GitHub](https://img.shields.io/github/license/openpotato/gv100ad-py)

# gv100ad-py

A Python library for parsing GV100AD files (Gemeindeverzeichnis) provided by [Destatis](https://www.destatis.de/DE/Themen/Laender-Regionen/Regionales/Gemeindeverzeichnis/_inhalt.html). 

+ Supports Python 3.8+
+ Supports all GV100AD record types:
  + Federal state (Bundesland, Satzart 10)
  + Government region (Regierungsbezirk, Satzart 20)
  + Region (Region, Satzart 30)
  + District (Kreis, Satzart 40)
  + Municipality (Gemeinde, Satzart 50)
  + Municipal association (Gemeindeverbund, Satzart 60)

## Installation

**gv100ad-py** is available on [PiPy](https://pypi.org/), and installation via [pip](https://pip.pypa.io/) is the recommended way to install:

```
pip install gv100ad-py
```

## Getting started

Documentation is available in the [GitHub wiki](https://github.com/openpotato/gv100ad-py/wiki).

## Can I help?

Yes, that would be much appreciated. The best way to help is to post a response via the Issue Tracker and/or submit a Pull Request.
